/* This testcase is part of GDB, the GNU debugger.

   Copyright 2010, 2011 Free Software Foundation, Inc.

   Contributed by Pierre Muller.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

   Test for Solaris specific watchpoint problem.  */

struct rec
{
 int x;
 double y;
 int z;
};

static struct rec myrec;

int
main ()
{
  myrec.x = 5;
  myrec.y = 3.4;
  myrec.z = 56;
  myrec.x = 78;
  return myrec.x;
}

